@@ -6,7 +6,7 @@ package Mite::Attribute;
 use Mite::Miteception qw( -all !lazy );
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.005004';
+our $VERSION   = '0.006000';
 
 has _order =>
   is            => rw,
@@ -58,7 +58,7 @@ has is =>
   isa           => Enum[ ro, rw, rwp, 'lazy', bare ],
   default       => bare;
 
-has [ 'reader', 'writer', 'accessor', 'clearer', 'predicate' ] =>
+has [ 'reader', 'writer', 'accessor', 'clearer', 'predicate', 'lvalue', 'local_writer' ] =>
   is            => rw,
   isa           => Str->where('length($_) > 0') | Undef,
   builder       => true,
@@ -149,22 +149,26 @@ for my $function ( qw/ carp croak confess / ) {
 
 my @method_name_generator = (
     { # public
-        reader      => sub { "get_$_" },
-        writer      => sub { "set_$_" },
-        accessor    => sub { $_ },
-        clearer     => sub { "clear_$_" },
-        predicate   => sub { "has_$_" },
-        builder     => sub { "_build_$_" },
-        trigger     => sub { "_trigger_$_" },
+        reader        => sub { "get_$_" },
+        writer        => sub { "set_$_" },
+        accessor      => sub { $_ },
+        lvalue        => sub { $_ },
+        clearer       => sub { "clear_$_" },
+        predicate     => sub { "has_$_" },
+        builder       => sub { "_build_$_" },
+        trigger       => sub { "_trigger_$_" },
+        local_writer  => sub { "locally_set_$_" },
     },
     { # private
-        reader      => sub { "_get_$_" },
-        writer      => sub { "_set_$_" },
-        accessor    => sub { $_ },
-        clearer     => sub { "_clear_$_" },
-        predicate   => sub { "_has_$_" },
-        builder     => sub { "_build_$_" },
-        trigger     => sub { "_trigger_$_" },
+        reader        => sub { "_get_$_" },
+        writer        => sub { "_set_$_" },
+        accessor      => sub { $_ },
+        lvalue        => sub { $_ },
+        clearer       => sub { "_clear_$_" },
+        predicate     => sub { "_has_$_" },
+        builder       => sub { "_build_$_" },
+        trigger       => sub { "_trigger_$_" },
+        local_writer  => sub { "_locally_set_$_" },
     },
 );
 
@@ -186,7 +190,7 @@ sub BUILD {
         }
     }
 
-    for my $property ( 'reader', 'writer', 'accessor', 'clearer', 'predicate', 'builder', 'trigger' ) {
+    for my $property ( 'reader', 'writer', 'accessor', 'clearer', 'predicate', 'builder', 'trigger', 'lvalue', 'local_writer' ) {
         my $name = $self->$property;
         if ( defined $name and $name eq true ) {
             my $gen = $method_name_generator[$self->is_private]{$property};
@@ -195,6 +199,25 @@ sub BUILD {
             $self->$property( $newname );
         }
     }
+
+    if ( defined $self->lvalue ) {
+        if ( $self->lazy ) {
+            require Mite::Shim;
+            Mite::Shim::croak( 'Attributes with lazy defaults cannot have an lvalue accessor' );
+        }
+        elsif ( $self->trigger ) {
+            require Mite::Shim;
+            Mite::Shim::croak( 'Attributes with triggers cannot have an lvalue accessor' );
+        }
+        elsif ( $self->weak_ref ) {
+            require Mite::Shim;
+            Mite::Shim::croak( 'Attributes with weak_ref cannot have an lvalue accessor' );
+        }
+        elsif ( $self->type or $self->coerce ) {
+            require Mite::Shim;
+            Mite::Shim::croak( 'Attributes with type constraints or coercions cannot have an lvalue accessor' );
+        }
+    }
 }
 
 sub _expand_name {
@@ -254,12 +277,16 @@ sub _build_predicate { undef; }
 
 sub _build_clearer { undef; }
 
+sub _build_lvalue { undef; }
+
+sub _build_local_writer { undef; }
+
 sub _build_alias_is_for {
     my $self = shift;
     return undef unless @{ $self->alias };
     my @seek_order = $self->is eq rw
-        ? qw( accessor reader writer )
-        : qw( reader accessor writer );
+        ? qw( accessor reader lvalue writer )
+        : qw( reader accessor lvalue writer );
     for my $sought ( @seek_order ) {
         return $sought if $self->$sought;
     }
@@ -567,6 +594,48 @@ my %code_template;
         my $self = shift;
         sprintf 'exists $_[0]{%s}', $self->_q_name;
     },
+    lvalue => sub {
+        my $self = shift;
+        sprintf '$_[0]{%s}', $self->_q_name;
+    },
+    local_writer => sub {
+        my $self = shift;
+
+        my $CROAK = $self->_function_for_croak;
+        my $GET = $self->reader ? $self->_q( $self->_expand_name( $self->reader ) )
+            : $self->accessor ? $self->_q( $self->_expand_name( $self->accessor ) )
+            : sprintf( 'sub { %s }', $code_template{reader}->( $self, no_croak => true ) );
+        my $SET = $self->writer ? $self->_q( $self->_expand_name( $self->writer ) )
+            : $self->accessor ? $self->_q( $self->_expand_name( $self->accessor ) )
+            : sprintf( 'sub { %s }', $code_template{writer}->( $self, label => 'local writer' ) );
+        my $HAS = $self->predicate ? $self->_q( $self->_expand_name( $self->predicate ) )
+            : sprintf( 'sub { %s }', $code_template{predicate}->( $self ) );
+        my $CLEAR = $self->clearer ? $self->_q( $self->_expand_name( $self->clearer ) )
+            : sprintf( 'sub { %s }', $code_template{clearer}->( $self ) );
+        my $SHIM = eval { $self->compiling_class->shim_name }
+            || eval { $self->class->shim_name }
+            || 'Scope::Guard';
+
+        return sprintf <<'CODE', $CROAK, $GET, $SET, $HAS, $CLEAR, $SHIM;
+
+    defined wantarray or %s( "This method cannot be called invoid context" );
+    my $get = %s;
+    my $set = %s;
+    my $has = %s;
+    my $clear = %s;
+    my $old = undef;
+    my ( $self, $new ) = @_;
+    my $restorer = $self->$has
+        ? do { $old = $self->$get; sub { $self->$set( $old ) } }
+        : sub { $self->$clear };
+    @_ == 2 ? $self->$set( $new ) : $self->$clear;
+    &%s::guard( $restorer, $old );
+CODE
+    },
+);
+
+my %code_attr = (
+    lvalue => ' :lvalue',
 );
 
 sub compile {
@@ -582,6 +651,7 @@ sub compile {
         writer    => 'setters',
         accessor  => 'accessors',
         predicate => 'exists_predicates',
+        lvalue    => 'lvalue_accessors',
     );
 
     my %want_xs;
@@ -629,16 +699,16 @@ sub compile {
         $code .= "}\n";
         $code .= "else {\n";
         for my $property ( sort keys %want_xs ) {
-            $code .= sprintf '    *%s = sub { %s };' . "\n",
-                $method_name{$property}, $code_template{$property}->($self);
+            $code .= sprintf '    *%s = sub%s { %s };' . "\n",
+                $method_name{$property}, $code_attr{$property} || '', $code_template{$property}->($self);
             delete $want_pp{$property};
         }
         $code .= "}\n";
     }
 
     for my $property ( sort keys %want_pp ) {
-        $code .= sprintf 'sub %s { %s }' . "\n",
-            $method_name{$property}, $code_template{$property}->($self);
+        $code .= sprintf 'sub %s%s { %s }' . "\n",
+            $method_name{$property}, $code_attr{$property} || '', $code_template{$property}->($self);
     }
 
     $code .= "\n";
